
def search4vowelz(phrase: str) -> set:
    """Return any vowels found in a supplied phrase."""
    vowels = set('aeiou')
    return vowels.intersection(set(phrase))


def search4vowels(phrase: str) -> set:
    """Return any vowels found in a supplied phrase."""
    vowels = set('aeiou')
    return vowels.intersection(set(phrase))


def search4letterz(phrase: str, letters: str='aeiou') -> set:
    """Return a set of the 'letters' found in 'phrase'."""
    return set(letters).intersection(set(phrase))



from setuptools import setup

setup(
    name='zsearch', 
    version='1.02', 
    description='The Head First Python Search Tools',
    author='HF Python 2e',
    author_email='azeltov@gmail.com',
    url='https://github.com/azeltov/adb_workshop',
    py_modules=['zsearch'],
    python_requires='>=3.6',
)
